﻿using Dto;
using Entities;
using Model.OrderCriteria;
using Shared;
using Shared.Mapper;

namespace API.Service;

public class InquiryDataServiceApi(IInquiryService<InquiryEntity> inquiryService) : IInquiryService<InquiryDTO>
{
    public async Task<InquiryDTO?> AddItem(InquiryDTO? item)
    {
        var inquiry = await inquiryService.AddItem(item.FromDTOToEntity());
        return inquiry.FromEntityToDTO();
    }
    public InquiryDTO UpdateInquiry(int id, InquiryDTO inquiry)
    {
        return inquiryService.UpdateInquiry(id, inquiry.FromDTOToEntity()).FromEntityToDTO();
    }

    public InquiryDTO CreateInquiry(string title, string description, bool isUser)
    {
        return inquiryService.CreateInquiry(title, description, isUser).FromEntityToDTO();
    }

    public bool DeleteInquiry(int id)
    {
        return inquiryService.DeleteInquiry(id);
    }
    public Task<bool> DeleteItem(int id)
    {
        return inquiryService.DeleteItem(id);
    }
    public IEnumerable<InquiryDTO> GetInquiries(int page, int number, InquiryOrderCriteria orderCriteria)
    {
        var inquiries = inquiryService.GetInquiries(page, number, orderCriteria);
        return inquiries.Select(i => i.FromEntityToDTO()).ToList();
    }
    public InquiryDTO GetInquiryById(int id) => inquiryService.GetInquiryById(id).FromEntityToDTO();

    public async Task<IEnumerable<InquiryDTO>> GetItems(int page, int count, object? orderCriteria = null, string? filter = null, object? valueFilter = null)
    {
       var inquiries = await inquiryService.GetItems(page, count, orderCriteria, filter, valueFilter);
        return inquiries.ToList().Select(i => i.FromEntityToDTO());
    }

    public InquiryEntity UpdateInquiry(int id, InquiryEntity inquiry)
    {
        return inquiryService.UpdateInquiry(id, inquiry);
    }

    public async Task<InquiryDTO> UpdateItem<TDto>(int? id, TDto? newItem) where TDto : class
    {
        var inquiry = await inquiryService.UpdateItem<TDto>(id, newItem);
        return inquiry.FromEntityToDTO();
    }
    public InquiryDTO GetInquiryByTitle(string title) => inquiryService.GetInquiryByTitle(title).FromEntityToDTO();
}