﻿using Dto;
using Entities;
using Model.OrderCriteria;
using Shared;
using Shared.Mapper;

namespace API.Service;

public class LessonDataServiceApi(ILessonService<LessonEntity> lessonService) : ILessonService<LessonDTO>
{
    public IEnumerable<LessonDTO> GetLessons(int page, int number, LessonOrderCriteria orderCriteria)
    {
        var lessonsEntities = lessonService.GetLessons(page, number, orderCriteria);
        return lessonsEntities.Select(e => e.FromEntityToDTO()).ToList();
    }

    public LessonDTO GetLessonById(int id) => lessonService.GetLessonById(id).FromEntityToDTO();

    public LessonDTO GetLessonByTitle(string title) => lessonService.GetLessonByTitle(title).FromEntityToDTO();

    public bool DeleteLesson(int id) => lessonService.DeleteLesson(id);

    public LessonDTO UpdateLesson(int id, LessonDTO lesson) =>
        lessonService.UpdateLesson(id, lesson.FromDTOToEntity()).FromEntityToDTO();
    public LessonDTO UpdateLesson(int id, LessonEntity lesson) =>
        lessonService.UpdateLesson(id, lesson).FromEntityToDTO();

    public LessonDTO CreateLesson(string title, string lastPublisher, DateOnly? lastEdit) =>
        lessonService.CreateLesson(title, lastPublisher, lastEdit).FromEntityToDTO();

    public async Task<LessonDTO?> AddItem(LessonDTO? item)
    {
        var lesson = await lessonService.AddItem(item.FromDTOToEntity());
        return lesson.FromEntityToDTO();
    }

    public async Task<bool> DeleteItem(int id)
    {
        var succes = await lessonService.DeleteItem(id);
        return succes;
    }

    public async Task<LessonDTO> UpdateItem<TDto>(int? id, TDto? newItem) where TDto : class
    {
        var lesson = await lessonService.UpdateItem(id, newItem);
        return lesson.FromEntityToDTO();
    }

    public async Task<IEnumerable<LessonDTO>> GetItems(int page, int count, object? orderCriteria = null, string? filter = null, object? valueFilter = null)
    {
        var lessons = await lessonService.GetItems(page, count, orderCriteria, filter, valueFilter);
        return lessons.ToList().Select(l => l.FromEntityToDTO());

    }
}