﻿using Dto;
using Entities;
using Model.OrderCriteria;
using Shared;
using Shared.Mapper;

namespace API.Service;

public class UserDataServiceApi(IUserService<UserEntity> userService) : IUserService<UserDTO>
{
    public IEnumerable<UserDTO> GetUsers(int page, int number, UserOrderCriteria orderCriteria)
    {
        var usersEntities = userService.GetUsers(page, number, orderCriteria);
        return usersEntities.Select(e => e.FromEntityToDTO()).ToList();
    }

    public UserDTO GetUserById(int id) => userService.GetUserById(id).FromEntityToDTO();

    public UserDTO GetUserByUsername(string username) => userService.GetUserByUsername(username).FromEntityToDTO();

    public bool DeleteUser(int id) => userService.DeleteUser(id);

    public UserDTO UpdateUser(int id, UserDTO user) =>
        userService.UpdateUser(id, user.FromDTOToEntity()).FromEntityToDTO();
    public UserDTO CreateUser(string username, string password, string email, bool isAdmin) =>
        userService.CreateUser(username, password, email, isAdmin).FromEntityToDTO();

    public async Task<UserDTO?> AddItem(UserDTO item)
    {
        var user = await userService.AddItem(item.FromDTOToEntity());
        return user.FromEntityToDTO();
    }

    public async Task<bool> DeleteItem(int id)
    {
        var sucess = await userService.DeleteItem(id);
        return sucess;
    }

    public async Task<UserDTO> UpdateItem<TDto>(int? id, TDto? newItem) where TDto : class
    {
        var user = await userService.UpdateItem<TDto>(id, newItem);
        return user.FromEntityToDTO();
    }

    public async Task<IEnumerable<UserDTO>> GetItems(int page, int count, object? orderCriteria = null, string? filter = null, object? valueFilter = null)
    {
        var usersEntities = await userService.GetItems(page, count, orderCriteria, filter, valueFilter);
        return usersEntities.Select(e => e.FromEntityToDTO()).ToList();
    }
}